#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 spdx
version:              1.1
visibility:           public
id:                   spdx-1.1-9Z89NOvDoglKGMtsrrvIF6
key:                  spdx-1.1-9Z89NOvDoglKGMtsrrvIF6
license:              BSD-3-Clause
copyright:            (c) 2015-2018 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/spdx
synopsis:             SPDX license expression language, Extras
description:
    Cabal provides SPDX types. This package provides some extras.

category:             Data
abi:                  c981611e5668d1a069a13f20f6e0766e
exposed:              True
exposed-modules:      Distribution.SPDX.Extra
import-dirs:          /usr/lib/ghc-9.6.6/site-local/spdx-1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/spdx-1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/spdx-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-spdx
hs-libraries:         HSspdx-1.1-9Z89NOvDoglKGMtsrrvIF6
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 containers-0.6.7
    puresat-0.1-Fadz90QBPfzKXAM0HBhrOp transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-spdx/html/spdx.haddock
haddock-html:         /usr/share/doc/haskell-spdx/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

